summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorIgor Murashkin <iam@google.com>2014-06-20 11:28:28 -0700
committerIgor Murashkin <iam@google.com>2014-06-20 13:07:19 -0700
commit9052efa196edb187d2abb24db8a4ccabac39438b (patch)
treed5073e30d908c395b21c5ee62c4bcebf3f8d5825
parent3372f0b9d87713fa9e6fb6a34dca02d7307b8229 (diff)
downloadmako-9052efa196edb187d2abb24db8a4ccabac39438b.tar.gz
camera: Return -EUSERS when too many cameras are open already
Change-Id: I08d9d1e30e72025c41bd54b702d7ae95b32257be
-rwxr-xr-xcamera/QualcommCamera2.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/camera/QualcommCamera2.cpp b/camera/QualcommCamera2.cpp
index 138dc27..79c2104 100755
--- a/camera/QualcommCamera2.cpp
+++ b/camera/QualcommCamera2.cpp
@@ -188,11 +188,11 @@ extern "C" int camera_device_open(
pthread_mutex_lock(&camera_session_lock);
//Return INVALID_OPERATION(-1) to framework if multiple camera instances detected.
if(QCameraSession) {
- ALOGE("%s Mutliple camera open instances are not supported",__func__);
+ ALOGE("%s Multiple camera open instances are not supported",__func__);
pthread_mutex_unlock(&camera_session_lock);
- return rc;
+ return -EUSERS;
}
if(module && id && hw_device) {
int cameraId = atoi(id);
@@ -188,11 +188,11 @@ extern "C" int camera_device_open(
pthread_mutex_lock(&camera_session_lock);
- //Return INVALID_OPERATION(-1) to framework if multiple camera instances detected.
+ //Return -EUSERS to framework if multiple camera instances detected.
if(QCameraSession) {